* Generic session options - page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=MAX formdlim=' ' spool; 									
* Kill default titles on output, ODS tables in log, turn on graphics; 
TITLE; ODS TRACE OFF; ODS LISTING ON; ODS GRAPHICS ON;

* Location for original files for these models  change this path;
%LET filesave = C:\Dropbox\Example Data\Sarah Mindfulness;
LIBNAME filesave "&filesave.";

* Bringing data into work library;
PROC IMPORT DATAFILE="&filesave.\Mindfullness Example.sav" 
	DBMS=SPSS OUT=work.Mindfull REPLACE; RUN;
DATA work.Mindfull; SET work.Mindfull; FORMAT _ALL_; 
* Center mindfulness (X);
	MindC = Mindful_Total1 - 2; 
* Renaming/creating other variables;
	* M1; Intern = MCS_Internal_Total;
	* M2; Extern = MCS_External_Total;
	* M3; Hostile = HS_Total;
	* M4; Benev = BS_Total;
	* Y;  NonTrad = (Feminists + Womens_Movement) /2;
	* Gender; SexMW = Sex_MFonly; * 0=Men, 1=Women;
RUN;
* Send to STATA;
PROC EXPORT DATA=work.Mindfull OUTFILE="&filesave.\Mindfull.dta" DBMS=STATA REPLACE; RUN;

* Split data by gender for multiple group model;
DATA work.Men;   SET work.Mindfull; WHERE SexMW=0; RUN;
DATA work.Women; SET work.Mindfull; WHERE SexMW=1; RUN;

* Open output directory to save results to;
ODS RTF FILE="&filesave.\SAS_Example8_Output.rtf" STYLE=HTMLBlue STARTPAGE=NO;

TITLE1 "Single-Group Path Model";
PROC CALIS DATA=work.Mindfull MEANSTR METHOD=FIML; *PLOTS=PATHDIAGRAM;
* VAR = List of variables in model;
  VAR  MindC Intern Extern Hostile Benev Nontrad;
* MEAN = Labeling means/intercepts per variable;
  MEAN MindC=Xint, Intern=M1int, Extern=M2int, Hostile=M3int, Benev=M4int, NonTrad=Yint;
* PVAR = Labeling variances/residual variances per variable;
  PVAR MindC=Xvar, Intern=M1var, Extern=M2var, Hostile=M3var, Benev=M4var, NonTrad=Yvar;
* PCOV = Requesting and labeling residual covariances;
  PCOV Intern Extern=CovM12, Intern Hostile=CovM13, Intern Benev=CovM14, 
       Extern Hostile=CovM23, Extern Benev=CovM24, Hostile Benev=Cov34;
* PATH = Model specification and labels;
  PATH MindC ---> NonTrad = mXtoY,
       MindC ---> Intern Extern Hostile Benev = XtoM1 XtoM2 XtoM3 XtoM4,
       Intern Extern Hostile Benev ---> NonTrad = M1toY M2toY M3toY M4toY;
* TESTFUNC = Requesting indirect effects;
  TESTFUNC XtoM1toY XtoM2toY XtoM3toY XtoM4toY; 
	       XtoM1toY = XtoM1*M1toY; XtoM2toY = XtoM2*M2toY; 
		   XtoM3toY = XtoM3*M3toY; XtoM4toY = XtoM4*M4toY; 
/* To make path diagram in SAS 9.4;
	 PATHDIAGRAM 
		TITLE="Mindfulness Mediation Example" SOLUTION=STANDARD
		ARRANGE=FLOW NOFITTABLE
	 	LABEL=[MindC="Mindfulness" Hostile="Hostile Sexism" Benev="Benevolent Sexism"
			   Intern="Internal Motivation" Extern="External Motivation" 
			   NonTrad="Warmth Towards Non-Traditional Women"]; */
RUN; TITLE1;

TITLE1 "Multiple-Group Path Model";
PROC CALIS DATA=work.Mindfull MEANSTR METHOD=FIML; *PLOTS=PATHDIAGRAM;
* VAR = List of variables in model;
  VAR  MindC Intern Extern Hostile Benev Nontrad;
* GROUP creates separate models (referred to by number);
  GROUP 1 / LABEL="Men"   DATA=work.Men; 
  GROUP 2 / LABEL="Women" DATA=work.Women; 
* Model for Men -- direct effects using M1 now labeled the same across groups;
  MODEL 1 / GROUP=1; 
  MEAN MindC=mXint, Intern=mM1int, Extern=mM2int, Hostile=mM3int, Benev=mM4int, NonTrad=mYint;
  PVAR MindC=mXvar, Intern=mM1var, Extern=mM2var, Hostile=mM3var, Benev=mM4var, NonTrad=mYvar;
  PCOV Intern Extern=mCovM12, Intern Hostile=mCovM13, Intern Benev=mCovM14, 
       Extern Hostile=mCovM23, Extern Benev=mCovM24, Hostile Benev=mCov34;
  PATH MindC ---> NonTrad = mXtoY,
       MindC ---> Intern Extern Hostile Benev = mXtoM1 mXtoM2 mXtoM3 mXtoM4,
       Intern Extern Hostile Benev ---> NonTrad = mM1toY mM2toY mM3toY mM4toY;
* Model for Women  -- direct effects using M1 now labeled the same across groups;
  MODEL 2 / GROUP=2; 
  MEAN MindC=wXint, Intern=wM1int, Extern=wM2int, Hostile=wM3int, Benev=wM4int, NonTrad=wYint;
  PVAR MindC=wXvar, Intern=wM1var, Extern=wM2var, Hostile=wM3var, Benev=wM4var, NonTrad=wYvar;
  PCOV Intern Extern=wCovM12, Intern Hostile=wCovM13, Intern Benev=wCovM14, 
       Extern Hostile=wCovM23, Extern Benev=wCovM24, Hostile Benev=wCov34;
  PATH MindC ---> NonTrad = wXtoY,
       MindC ---> Intern Extern Hostile Benev = wXtoM1 wXtoM2 wXtoM3 wXtoM4,
       Intern Extern Hostile Benev ---> NonTrad = wM1toY wM2toY wM3toY wM4toY;
* Indirect Effects for Both Groups;
  TESTFUNC mXtoM1toY wXtoM1toY mXtoM2toY wXtoM2toY mXtoM3toY wXtoM3toY mXtoM4toY wXtoM4toY; 
  	       mXtoM1toY = mXtoM1*mM1toY; wXtoM1toY = wXtoM1*wM1toY;
	       mXtoM2toY = mXtoM2*mM2toY; wXtoM2toY = wXtoM2*wM2toY;
		   mXtoM3toY = mXtoM2*mM2toY; wXtoM3toY = wXtoM3*wM3toY;
		   mXtoM4toY = mXtoM2*mM2toY; wXtoM4toY = wXtoM4*wM4toY;
/* To make path diagram in SAS 9.4;
	 PATHDIAGRAM 
		TITLE="Mindfulness Mediation Example" SOLUTION=STANDARD
		ARRANGE=FLOW NOFITTABLE
	 	LABEL=[MindC="Mindfulness" Hostile="Hostile Sexism" Benev="Benevolent Sexism"
			   Intern="Internal Motivation" Extern="External Motivation" 
			   NonTrad="Warmth Towards Non-Traditional Women"]; */
RUN; TITLE1;

TITLE1 "Multiple-Group Path Model -- XtoM1toY equal by gender";
TITLE2 "Model chi-square provides test of 2 new constraints";
PROC CALIS DATA=work.Mindfull MEANSTR METHOD=FIML; *PLOTS=PATHDIAGRAM;
* VAR = List of variables in model;
  VAR  MindC Intern Extern Hostile Benev Nontrad;
* GROUP creates separate models (referred to by number);
  GROUP 1 / LABEL="Men"   DATA=work.Men; 
  GROUP 2 / LABEL="Women" DATA=work.Women; 
* Model for Men -- all parameters are now labeled separately for full non-invariance;
  MODEL 1 / GROUP=1; 
  MEAN MindC=mXint, Intern=mM1int, Extern=mM2int, Hostile=mM3int, Benev=mM4int, NonTrad=mYint;
  PVAR MindC=mXvar, Intern=mM1var, Extern=mM2var, Hostile=mM3var, Benev=mM4var, NonTrad=mYvar;
  PCOV Intern Extern=mCovM12, Intern Hostile=mCovM13, Intern Benev=mCovM14, 
       Extern Hostile=mCovM23, Extern Benev=mCovM24, Hostile Benev=mCov34;
  PATH MindC ---> NonTrad = mXtoY,
       MindC ---> Intern Extern Hostile Benev = XtoM1 mXtoM2 mXtoM3 mXtoM4,
       Intern Extern Hostile Benev ---> NonTrad = M1toY mM2toY mM3toY mM4toY;
* Model for Women  -- all parameters are now labeled separately for full non-invariance;;
  MODEL 2 / GROUP=2; 
  MEAN MindC=wXint, Intern=wM1int, Extern=wM2int, Hostile=wM3int, Benev=wM4int, NonTrad=wYint;
  PVAR MindC=wXvar, Intern=wM1var, Extern=wM2var, Hostile=wM3var, Benev=wM4var, NonTrad=wYvar;
  PCOV Intern Extern=wCovM12, Intern Hostile=wCovM13, Intern Benev=wCovM14, 
       Extern Hostile=wCovM23, Extern Benev=wCovM24, Hostile Benev=wCov34;
  PATH MindC ---> NonTrad = wXtoY,
       MindC ---> Intern Extern Hostile Benev = XtoM1 wXtoM2 wXtoM3 wXtoM4,
       Intern Extern Hostile Benev ---> NonTrad = M1toY wM2toY wM3toY wM4toY;
* Indirect Effects for Both Groups;
  TESTFUNC XtoM1toY mXtoM2toY wXtoM2toY mXtoM3toY wXtoM3toY mXtoM4toY wXtoM4toY; 
  	        XtoM1toY =  XtoM1*M1toY; 
	       mXtoM2toY = mXtoM2*mM2toY; wXtoM2toY = wXtoM2*wM2toY;
		   mXtoM3toY = mXtoM2*mM2toY; wXtoM3toY = wXtoM3*wM3toY;
		   mXtoM4toY = mXtoM2*mM2toY; wXtoM4toY = wXtoM4*wM4toY;
/* To make path diagram in SAS 9.4;
	 PATHDIAGRAM 
		TITLE="Mindfulness Mediation Example" SOLUTION=STANDARD
		ARRANGE=FLOW NOFITTABLE
	 	LABEL=[MindC="Mindfulness" Hostile="Hostile Sexism" Benev="Benevolent Sexism"
			   Intern="Internal Motivation" Extern="External Motivation" 
			   NonTrad="Warmth Towards Non-Traditional Women"]; */
RUN; TITLE1; TITLE2;

* Close output;
ODS RTF CLOSE;
