* Prevent "more" messages from appearing
set more off, permanently
* Control line length
set linesize 150

* Defining global variable for file location to be replaced in code below
global filesave "C:\Dropbox\Example Data\Sarah Mindfulness"
 
* Import example data file 
use "$filesave\Mindfull.dta", clear

* Save results to separate file
log using $filesave\STATA_Example8_Output.log, replace name(Example8)

* /// means continue the command + comment
*  // means comment only
* sem, standardized // print standardized effects this time

display as result "Single group path model"
display as result "Using coeflegend to get parm labels"
sem (mindc -> nontrad) 						                     	/// XtoY
    (mindc -> intern extern hostile benev)  	      /// XtoM1,M2,M3,M4
	   (intern extern hostile benev -> nontrad),      /// M1,M2,M3,M4toY
	 means(mindc)                                     /// print mean
		  var(mindc)                                     /// print variance
	 covariance(e.intern*e.extern e.intern*e.hostile) /// residual covariances
	 covariance(e.intern*e.benev  e.extern*e.hostile) /// residual covariances
	 covariance(e.extern*e.benev  e.hostile*e.benev)  /// residual covariances
	 method(mlmv) 							                            	/// full-information ML
	 coeflegend,  								                             // display parm labels 
	 estat eqgof, 								                             // R2 per variable
	 estat gof, stats(all) 					 	                     // model fit
	 
display as result "Single group path model omitting coeflegend"
display as result "Adding indirect effects (that use parm labels)"
sem (mindc -> nontrad) 						                     	/// XtoY
    (mindc -> intern extern hostile benev)  	      /// XtoM1,M2,M3,M4
	   (intern extern hostile benev -> nontrad),      /// M1,M2,M3,M4toY
	 means(mindc)                                     /// print mean
		  var(mindc)                                     /// print variance
	 covariance(e.intern*e.extern e.intern*e.hostile) /// residual covariances
	 covariance(e.intern*e.benev  e.extern*e.hostile) /// residual covariances
	 covariance(e.extern*e.benev  e.hostile*e.benev)  /// residual covariances
	 method(mlmv), 							                            	// full-information ML
	 estat eqgof, 								                             // R2 per variable
	 estat gof, stats(all), 			  	                     // model fit
	 nlcom _b[intern:mindc]*_b[nontrad:intern]   // indirect effect XtoM1toY
	 nlcom _b[extern:mindc]*_b[nontrad:extern]   // indirect effect XtoM2toY
	 nlcom _b[hostile:mindc]*_b[nontrad:hostile] // indirect effect XtoM3toY
	 nlcom _b[benev:mindc]*_b[nontrad:benev]     // indirect effect XtoM4toY

display as result "Multiple group path model"
display as result "Using coeflegend to get parm labels"
sem (mindc -> nontrad) 						                     	/// XtoY
    (mindc -> intern extern hostile benev)  	      /// XtoM1,M2,M3,M4
   	(intern extern hostile benev -> nontrad),      /// M1,M2,M3,M4toY
		means(mindc)                                     /// print mean
		  var(mindc)                                     /// print variance
	 covariance(e.intern*e.extern e.intern*e.hostile) /// residual covariances
	 covariance(e.intern*e.benev  e.extern*e.hostile) /// residual covariances
	 covariance(e.extern*e.benev  e.hostile*e.benev)  /// residual covariances
	 method(mlmv) 							                            	/// full-information ML
	 coeflegend  							                             	/// display parm labels 
	 group(sexmw) ginvariant(none),                    // none= full non-invariance
	 estat eqgof, 								                             // R2 per variable
	 estat gof, stats(all), 				                       // model fit
	 estat ginvariant,			          // Wald or Score test for each parm's invariance
								                        // Wald  = test of constraining equal if unequal
								                        // Score = test of allowing unequal if equal
	 
display as result "Multiple group path model omitting coeflegened"
display as result "Adding indirect effects (that use parm labels)"
sem (mindc -> nontrad) 						                     	/// XtoY
    (mindc -> intern extern hostile benev) 	       /// XtoM1,M2,M3,M4
	   (intern extern hostile benev -> nontrad),      /// M1,M2,M3,M4toY
		means(mindc)                                     /// print mean
		  var(mindc)                                     /// print variance
	 covariance(e.intern*e.extern e.intern*e.hostile) /// residual covariances
	 covariance(e.intern*e.benev  e.extern*e.hostile) /// residual covariances
	 covariance(e.extern*e.benev  e.hostile*e.benev)  /// residual covariances
	 method(mlmv) 							                            	/// full-information ML
	 group(sexmw) ginvariant(none),                    // none= full non-invariance
	 estat eqgof, 								                             // R2 per variable
	 estat gof, stats(all), 				                       // model fit
	 estat ginvariant,			          // Wald or Score test for each parm's invariance
								                        // Wald  = test of constraining equal if unequal
								                        // Score = test of allowing unequal if equal
	 // men and women indirect effect XtoM1toY
	 nlcom _b[intern:0bn.sexmw#c.mindc]*_b[nontrad:0bn.sexmw#c.intern]  
	 nlcom _b[intern:1.sexmw#c.mindc]*_b[nontrad:1.sexmw#c.intern]
	 // men and women indirect effect XtoM2toY
	 nlcom _b[extern:0bn.sexmw#c.mindc]*_b[nontrad:0bn.sexmw#c.extern]
	 nlcom _b[extern:1.sexmw#c.mindc]*_b[nontrad:1.sexmw#c.extern]
	 // men and women indirect effect XtoM3toY
	 nlcom _b[hostile:0bn.sexmw#c.mindc]*_b[nontrad:0bn.sexmw#c.hostile]
	 nlcom _b[hostile:1.sexmw#c.mindc]*_b[nontrad:1.sexmw#c.hostile]
	 // men and women indirect effect XtoM4toY
	 nlcom _b[benev:0bn.sexmw#c.mindc]*_b[nontrad:0bn.sexmw#c.benev] 
	 nlcom _b[benev:1.sexmw#c.mindc]*_b[nontrad:1.sexmw#c.benev] 

display as result "Multiple group path model omitting coeflegened"
display as result "Testing equality of indirect effect XtoM1toY"
display as result "Model chi-square gives test of 2 new constraints"
sem (mindc -> nontrad) 						                     	/// XtoY
    (0: mindc -> intern@a extern hostile benev) 	  /// XtoM1,M2,M3,M4 for group0
				(1: mindc -> intern@a extern hostile benev) 	  /// XtoM1,M2,M3,M4 for group1
	   (0: nontrad <- intern@b extern hostile benev)  /// M1,M2,M3,M4toY for group0
				(1: nontrad <- intern@b extern hostile benev), /// M1,M2,M3,M4toY for group1
		means(mindc)                                     /// print mean
		  var(mindc)                                     /// print variance
	 covariance(e.intern*e.extern e.intern*e.hostile) /// residual covariances
	 covariance(e.intern*e.benev  e.extern*e.hostile) /// residual covariances
	 covariance(e.extern*e.benev  e.hostile*e.benev)  /// residual covariances
	 method(mlmv) 							                            	/// full-information ML
	 group(sexmw) ginvariant(none),                    // none= full non-invariance
	 estat eqgof, 								                             // R2 per variable
	 estat gof, stats(all), 				                       // model fit
	 estat ginvariant,			          // Wald or Score test for each parm's invariance
								                        // Wald  = test of constraining equal if unequal
								                        // Score = test of allowing unequal if equal
	 // men and women indirect effect XtoM1toY
	 nlcom _b[intern:0bn.sexmw#c.mindc]*_b[nontrad:0bn.sexmw#c.intern]  
	 nlcom _b[intern:1.sexmw#c.mindc]*_b[nontrad:1.sexmw#c.intern]
	 
 * Close log	
 log close Example8

